@@ -12,7 +12,10 @@ gcrypt_ffi = FFI()
 gcrypt_ffi.include(gerror_ffi)
 
 # I want to have the source in a _gcrypt module
-gcrypt_ffi.set_source("pygcrypt._gcrypt", None)
+gcrypt_ffi.set_source("pygcrypt._gcrypt", r"""
+        #include <gcrypt.h>
+        """,
+        libraries=['gcrypt'])
 
 # Now, let's build the gcrypt lib
 gcrypt_ffi.cdef("""
@@ -47,23 +50,6 @@ gcrypt_ffi.cdef("""
         gcry_err_code_t gcry_error_from_errno (int err);
         """)
 
-gcrypt_ffi.cdef("""
-        /* NOTE: Since Libgcrypt 1.6 the thread callbacks are not anymore
-           used.  However we keep it to allow for some source code
-           compatibility if used in the standard way.  */
-
-        /* Wrapper for struct ath_ops.  */
-        struct gcry_thread_cbs
-        {
-          /* The OPTION field encodes the thread model and the version number
-             of this structure.
-               Bits  7 - 0  are used for the thread model
-               Bits 15 - 8  are used for the version number.  */
-          unsigned int option;
-        } _GCRY_ATTR_INTERNAL;
-
-        """)
-
 gcrypt_ffi.cdef("""
         /* A generic context object as used by some functions.  */
         struct gcry_context;
