@@ -4,8 +4,8 @@ import pytest
 
 import pygcrypt.errors as errors
 from pygcrypt.ecurve import ECurve
-from pygcrypt.types.mpi import MPIint
-from pygcrypt.types.sexpression import SExpression
+from pygcrypt.gctypes.mpi import MPIint
+from pygcrypt.gctypes.sexpression import SExpression
 
 def test_get(context):
     ec = ECurve(curve='secp192r1')
